@@ -40,10 +40,50 @@
 #include "MediaInfo/Audio/File_Adm.h"
 #include "ThirdParty/tfsxml/tfsxml.h"
 using namespace ZenLib;
+using namespace std;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
 {
+
+//---------------------------------------------------------------------------
+static float32 TimeCodeToFloat(string v)
+{
+    if (v.size() < 8 || v[2] != ':' || v[5] != ':')
+        return 0;
+    for (int i = 0; i < 8; i++)
+    {
+        switch (i)
+        {
+        case 2:
+        case 5:
+            if (v[i] != ':')
+                return 0;
+            break;
+        default:
+            if (v[i] < '0' || v[i] > '9')
+                return 0;
+        }
+    }
+    float32 Value = (v[0] - '0') * 10 * 6 * 10 * 6 * 10
+                  + (v[1] - '0')      * 6 * 10 * 6 * 10
+                  + (v[3] - '0')          * 10 * 6 * 10
+                  + (v[4] - '0')               * 6 * 10
+                  + (v[6] - '0')                   * 10
+                  + (v[7] - '0')                       ;
+    if (v.size() < 9 || v[8] != '.')
+        return Value;
+    int i = 9;
+    float32 Divider = 1;
+    while (i < v.size() && v[i] >= '0' && v[i] <= '9')
+    {
+        Divider *= 10;
+        Value += ((float32)(v[i] - '0')) / Divider;
+        i++;
+    }
+    return Value;
+}
+
 //---------------------------------------------------------------------------
 static const char* profile_names[]=
 {
@@ -140,6 +180,7 @@ struct element {
 };
 
 enum items {
+    item_audioTrack,
     item_audioProgramme,
     item_audioContent,
     item_audioObject,
@@ -151,6 +192,16 @@ enum items {
     item_Max
 };
 
+enum audioTrack_String {
+    audioTrack_Summary,
+    audioTrack_String_Max
+};
+
+enum audioTrack_StringVector {
+    audioTrack_audioTrackUIDRef,
+    audioTrack_StringVector_Max
+};
+
 enum audioProgramme_String {
     audioProgramme_audioProgrammeID,
     audioProgramme_audioProgrammeName,
@@ -380,21 +431,46 @@ static void Apply_SubStreams(File__Analyze& F, const string& P_And_LinkedTo, con
 class file_adm_private
 {
 public:
-    tfsxml_string p;
+    // In
+    bool IsSub;
+
+    // Out
     Items_Struct Items[item_Max];
     int Version;
     bool DolbyProfileCanNotBeVersion1;
     vector<profile_info> profileInfos;
+    map<string, string> More;
 
-    void parse();
-    void coreMetadata();
-    void format();
-    void audioFormatExtended();
-
+    // Constructor / Destructor
     file_adm_private() {
         Version = 0;
         DolbyProfileCanNotBeVersion1 = false;
     };
+
+    // Actions
+    void parse();
+
+    // Helpers
+    void chna_Add(int32u Index, const string& TrackUID)
+    {
+        if (Index >= 0x10000)
+            return;
+        if (Items[item_audioTrack].Items.empty())
+            Items[item_audioTrack].Init(audioTrack_String_Max, audioTrack_StringVector_Max);
+        while (Items[item_audioTrack].Items.size() <= Index)
+            Items[item_audioTrack].New();
+        Item_Struct& Item = Items[item_audioTrack].Items[Items[item_audioTrack].Items.size() - 1];
+        Item.StringVectors[audioTrack_audioTrackUIDRef].push_back(TrackUID);
+    }
+
+//private:
+    tfsxml_string p;
+
+    void coreMetadata();
+    void format();
+    void audioFormatExtended();
+    void frameHeader();
+    void transportTrackFormat();
 };
 
 void file_adm_private::parse()
@@ -404,6 +480,7 @@ void file_adm_private::parse()
     # define STRUCTS(NAME) \
         Items[item_##NAME].Init(NAME##_String_Max, NAME##_StringVector_Max);
 
+    STRUCTS(audioTrack);
     STRUCTS(audioProgramme);
     STRUCTS(audioContent);
     STRUCTS(audioObject);
@@ -415,7 +492,7 @@ void file_adm_private::parse()
 
     
     #define ELEMENT_START(NAME) \
-        if (!tfsxml_cmp_charp(b, #NAME)) \
+        if (!tfsxml_strcmp_charp(b, #NAME)) \
         { \
             Item_Struct& NAME##_Content = Items[item_##NAME].New(); \
             for (;;) { \
@@ -425,77 +502,81 @@ void file_adm_private::parse()
                 } \
 
     #define ELEMENT_MIDDLE(NAME) \
-                else if (tfsxml_cmp_charp(b, "typeLabel")) { \
-                    NAME##_Content.Errors[Warning].push_back("Attribute \"" + string(b.buf, b.len) + "\" is out of specs"); \
+                else if (tfsxml_strcmp_charp(b, "typeLabel")) { \
+                    NAME##_Content.Errors[Warning].push_back("Attribute \"" + tfsxml_decode(b) + "\" is out of specs"); \
                 } \
             } \
-        tfsxml_enter(&p, &b); \
-        for (;;) { \
-            if (tfsxml_next(&p, &b)) \
-                break; \
-            if (false) { \
-            } \
+        if (!tfsxml_enter(&p)) \
+        { \
+            for (;;) { \
+                if (tfsxml_next(&p, &b)) \
+                    break; \
+                if (false) { \
+                } \
 
     #define ELEMENT_END(NAME) \
-                else if (tfsxml_cmp_charp(b, "loudnessMetadata") && tfsxml_cmp_charp(b, "authoringInformation") && tfsxml_cmp_charp(b, "alternativeValueSetIDRef")) { \
-                    NAME##_Content.Errors[Warning].push_back("Element \"" + string(b.buf, b.len) + "\" is out of specs"); \
+                    else if (tfsxml_strcmp_charp(b, "loudnessMetadata") && tfsxml_strcmp_charp(b, "authoringInformation") && tfsxml_strcmp_charp(b, "alternativeValueSetIDRef")) { \
+                        NAME##_Content.Errors[Warning].push_back("Element \"" + tfsxml_decode(b) + "\" is out of specs"); \
+                    } \
                 } \
             } \
         } \
 
     #define ATTRIBUTE(NAME,ATTR) \
-        else if (!tfsxml_cmp_charp(b, #ATTR)) { \
-            NAME##_Content.Strings[NAME##_##ATTR].assign(v.buf, v.len); \
+        else if (!tfsxml_strcmp_charp(b, #ATTR)) { \
+            NAME##_Content.Strings[NAME##_##ATTR].assign(tfsxml_decode(v)); \
         } \
 
     #define ATTRIBUTE_I(NAME,ATTR) \
-        else if (!tfsxml_cmp_charp(b, #ATTR)) { \
+        else if (!tfsxml_strcmp_charp(b, #ATTR)) { \
         } \
 
     #define ELEMENT(NAME,ELEM) \
-        else if (!tfsxml_cmp_charp(b, #ELEM)) { \
+        else if (!tfsxml_strcmp_charp(b, #ELEM)) { \
             tfsxml_value(&p, &b); \
-            NAME##_Content.StringVectors[NAME##_##ELEM].push_back(string(b.buf, b.len)); \
+            NAME##_Content.StringVectors[NAME##_##ELEM].push_back(tfsxml_decode(b)); \
         } \
 
     #define ELEMENT_I(NAME,ELEM) \
-        else if (!tfsxml_cmp_charp(b, #ELEM)) { \
+        else if (!tfsxml_strcmp_charp(b, #ELEM)) { \
         } \
 
     for (;;) {
         if (tfsxml_next(&p, &b))
             break;
-        if (!tfsxml_cmp_charp(b, "audioFormatExtended"))
+        if (!tfsxml_strcmp_charp(b, "audioFormatExtended"))
         {
             audioFormatExtended();
         }
-        if (!tfsxml_cmp_charp(b, "ebuCoreMain"))
+        if (!tfsxml_strcmp_charp(b, "ebuCoreMain"))
         {
             while (!tfsxml_attr(&p, &b, &v)) {
-                if (!tfsxml_cmp_charp(b, "xmlns") || !tfsxml_cmp_charp(b, "xsi:schemaLocation")) {
+                if (!tfsxml_strcmp_charp(b, "xmlns") || !tfsxml_strcmp_charp(b, "xsi:schemaLocation")) {
                     DolbyProfileCanNotBeVersion1 = false;
-                    if (!tfsxml_str_charp(v, "ebuCore_2014").len && !tfsxml_str_charp(v, "ebuCore_2016").len) {
+                    if (!tfsxml_strstr_charp(v, "ebuCore_2014").len && !tfsxml_strstr_charp(v, "ebuCore_2016").len) {
                         DolbyProfileCanNotBeVersion1 = true;
                     }
                     if (!DolbyProfileCanNotBeVersion1)
                         break;
                 }
             }
-            tfsxml_enter(&p, &b);
-            for (;;) {
-                if (tfsxml_next(&p, &b))
-                    break;
-                if (!tfsxml_cmp_charp(b, "coreMetadata"))
-                {
-                    coreMetadata();
+            if (!tfsxml_enter(&p))
+            {
+                for (;;) {
+                    if (tfsxml_next(&p, &b))
+                        break;
+                    if (!tfsxml_strcmp_charp(b, "coreMetadata"))
+                    {
+                        coreMetadata();
+                    }
                 }
             }
         }
-        if (!tfsxml_cmp_charp(b, "frame"))
+        if (!tfsxml_strcmp_charp(b, "frame"))
         {
             format();
         }
-        if (!tfsxml_cmp_charp(b, "format"))
+        if (!tfsxml_strcmp_charp(b, "format"))
         {
             format();
         }
@@ -506,11 +587,11 @@ void file_adm_private::coreMetadata()
 {
     tfsxml_string b;
 
-    tfsxml_enter(&p, &b);
+    tfsxml_enter(&p);
     for (;;) {
         if (tfsxml_next(&p, &b))
             break;
-        if (!tfsxml_cmp_charp(b, "format"))
+        if (!tfsxml_strcmp_charp(b, "format"))
         {
             format();
         }
@@ -521,27 +602,27 @@ void file_adm_private::format()
 {
     tfsxml_string b, v;
 
-    tfsxml_enter(&p, &b);
+    tfsxml_enter(&p);
     for (;;) {
         if (tfsxml_next(&p, &b))
             break;
-        if (!tfsxml_cmp_charp(b, "audioFormatCustom")) {
-            tfsxml_enter(&p, &b);
+        if (!tfsxml_strcmp_charp(b, "audioFormatCustom")) {
+            tfsxml_enter(&p);
             while (!tfsxml_next(&p, &b)) {
-                if (!tfsxml_cmp_charp(b, "audioFormatCustomSet")) {
-                    tfsxml_enter(&p, &b);
+                if (!tfsxml_strcmp_charp(b, "audioFormatCustomSet")) {
+                    tfsxml_enter(&p);
                     while (!tfsxml_next(&p, &b)) {
-                        if (!tfsxml_cmp_charp(b, "admInformation")) {
-                            tfsxml_enter(&p, &b);
+                        if (!tfsxml_strcmp_charp(b, "admInformation")) {
+                            tfsxml_enter(&p);
                             while (!tfsxml_next(&p, &b)) {
-                                if (!tfsxml_cmp_charp(b, "profile")) {
+                                if (!tfsxml_strcmp_charp(b, "profile")) {
                                     profileInfos.resize(profileInfos.size() + 1);
                                     profile_info& profileInfo = profileInfos[profileInfos.size() - 1];
                                     while (!tfsxml_attr(&p, &b, &v)) {
                                         for (size_t i = 0; i < profile_names_size; i++)
                                         {
-                                            if (!tfsxml_cmp_charp(b, profile_names[i])) {
-                                                profileInfo.Strings[i] = string(v.buf, v.len);
+                                            if (!tfsxml_strcmp_charp(b, profile_names[i])) {
+                                                profileInfo.Strings[i] = tfsxml_decode(v);
                                                 if (!i && profileInfo.Strings[0].size() >= 12 && !profileInfo.Strings[0].compare(profileInfo.Strings[0].size() - 12, 12, " ADM Profile"))
                                                     profileInfo.Strings[0].resize(profileInfo.Strings[0].size() - 12);
                                             }
@@ -556,9 +637,12 @@ void file_adm_private::format()
                 }
             }
         }
-        if (!tfsxml_cmp_charp(b, "audioFormatExtended")) {
+        if (!tfsxml_strcmp_charp(b, "audioFormatExtended")) {
             audioFormatExtended();
         }
+        if (!tfsxml_strcmp_charp(b, "frameHeader")) {
+            frameHeader();
+        }
     }
 }
 
@@ -567,16 +651,16 @@ void file_adm_private::audioFormatExtended()
     tfsxml_string b, v;
 
     while (!tfsxml_attr(&p, &b, &v)) {
-        if (!tfsxml_cmp_charp(b, "version")) {
-            if (!tfsxml_cmp_charp(v, "ITU-R_BS.2076-1")) {
+        if (!tfsxml_strcmp_charp(b, "version")) {
+            if (!tfsxml_strcmp_charp(v, "ITU-R_BS.2076-1")) {
                 Version = 1;
             }
-            if (!tfsxml_cmp_charp(v, "ITU-R_BS.2076-2")) {
+            if (!tfsxml_strcmp_charp(v, "ITU-R_BS.2076-2")) {
                 Version = 2;
             }
         }
     }
-    tfsxml_enter(&p, &b);
+    tfsxml_enter(&p);
     for (;;) {
         if (tfsxml_next(&p, &b))
             break;
@@ -588,17 +672,17 @@ void file_adm_private::audioFormatExtended()
             ATTRIBUTE(audioProgramme, end)
         ELEMENT_MIDDLE(audioProgramme)
             ELEMENT(audioProgramme, audioContentIDRef)
-            else if (!tfsxml_cmp_charp(b, "audioProgrammeLabel")) {
+            else if (!tfsxml_strcmp_charp(b, "audioProgrammeLabel")) {
                 string Language;
                 for (;;) {
                     if (tfsxml_attr(&p, &b, &v))
                         break;
-                    if (!tfsxml_cmp_charp(b, "language")) {
-                        Language += string(v.buf, v.len);
+                    if (!tfsxml_strcmp_charp(b, "language")) {
+                        Language += tfsxml_decode(v);
                     }
                 }
                 tfsxml_value(&p, &b);
-                string Value = string(b.buf, b.len);
+                string Value = tfsxml_decode(b);
                 if (!Value.empty() && !Language.empty()) {
                     Value.insert(0, '(' + Language + ')');
                 }
@@ -612,20 +696,20 @@ void file_adm_private::audioFormatExtended()
             ATTRIBUTE(audioContent, typeLabel)
         ELEMENT_MIDDLE(audioContent)
             ELEMENT(audioContent, audioObjectIDRef)
-            else if (!tfsxml_cmp_charp(b, "dialogue")) {
+            else if (!tfsxml_strcmp_charp(b, "dialogue")) {
                 string Type;
                 for (;;) {
                     if (tfsxml_attr(&p, &b, &v))
                         break;
-                    if (!tfsxml_cmp_charp(b, "nonDialogueContentKind")
-                        || !tfsxml_cmp_charp(b, "dialogueContentKind")
-                        || !tfsxml_cmp_charp(b, "mixedContentKind")) {
-                        Type += string(v.buf, v.len);
+                    if (!tfsxml_strcmp_charp(b, "nonDialogueContentKind")
+                        || !tfsxml_strcmp_charp(b, "dialogueContentKind")
+                        || !tfsxml_strcmp_charp(b, "mixedContentKind")) {
+                        Type += tfsxml_decode(v);
                     }
                 }
                 tfsxml_value(&p, &b);
                 string Value;
-                if (!tfsxml_cmp_charp(b, "0")) {
+                if (!tfsxml_strcmp_charp(b, "0")) {
                     if (Type == "1") {
                         Value = "Music";
                     }
@@ -639,7 +723,7 @@ void file_adm_private::audioFormatExtended()
                         }
                     }
                 }
-                else if (!tfsxml_cmp_charp(b, "1")) {
+                else if (!tfsxml_strcmp_charp(b, "1")) {
                     if (Type == "1") {
                         Value = "Music";
                     }
@@ -665,7 +749,7 @@ void file_adm_private::audioFormatExtended()
                         }
                     }
                 }
-                else if (!tfsxml_cmp_charp(b, "2")) {
+                else if (!tfsxml_strcmp_charp(b, "2")) {
                     if (Type == "1") {
                         Value = "Complete Main";
                     }
@@ -683,37 +767,39 @@ void file_adm_private::audioFormatExtended()
                     }
                 }
                 else {
-                    Value = string(b.buf, b.len);
+                    Value = tfsxml_decode(b);
                     if (!Type.empty()) {
                         Value += " (" + Type + ')';
                     }
                 }
                 audioContent_Content.StringVectors[audioContent_dialogue].push_back(Value);
             }
-            else if (!tfsxml_cmp_charp(b, "audioContentLabel")) {
+            else if (!tfsxml_strcmp_charp(b, "audioContentLabel")) {
                 string Language;
                 for (;;) {
                     if (tfsxml_attr(&p, &b, &v))
                         break;
-                    if (!tfsxml_cmp_charp(b, "language")) {
-                        Language += string(v.buf, v.len);
+                    if (!tfsxml_strcmp_charp(b, "language")) {
+                        Language += tfsxml_decode(v);
                     }
                 }
                 tfsxml_value(&p, &b);
-                string Value = string(b.buf, b.len);
+                string Value = tfsxml_decode(b);
                 if (!Value.empty() && !Language.empty()) {
                     Value.insert(0, '(' + Language + ')');
                 }
                 audioContent_Content.StringVectors[audioContent_audioContentLabel].push_back(Value);
             }
-            if (!tfsxml_cmp_charp(b, "loudnessMetadata")) {
-                tfsxml_enter(&p, &b);
-                for (;;) {
-                    if (tfsxml_next(&p, &b))
-                        break;
-                    if (!tfsxml_cmp_charp(b, "integratedLoudness")) {
-                        tfsxml_value(&p, &b);
-                        audioContent_Content.StringVectors[audioContent_integratedLoudness].push_back(string(b.buf, b.len));
+            if (!tfsxml_strcmp_charp(b, "loudnessMetadata")) {
+                if (!tfsxml_enter(&p))
+                {
+                    for (;;) {
+                        if (tfsxml_next(&p, &b))
+                            break;
+                        if (!tfsxml_strcmp_charp(b, "integratedLoudness")) {
+                            tfsxml_value(&p, &b);
+                            audioContent_Content.StringVectors[audioContent_integratedLoudness].push_back(tfsxml_decode(b));
+                        }
                     }
                 }
             }
@@ -743,29 +829,31 @@ void file_adm_private::audioFormatExtended()
             ATTRIBUTE(audioChannelFormat, typeDefinition)
             ATTRIBUTE(audioChannelFormat, typeLabel)
         ELEMENT_MIDDLE(audioChannelFormat)
-            else if (!tfsxml_cmp_charp(b, "audioBlockFormat")) {
-                tfsxml_enter(&p, &b);
-                for (;;) {
-                    if (tfsxml_next(&p, &b))
-                        break;
-                    if (!tfsxml_cmp_charp(b, "speakerLabel")) {
-                        tfsxml_value(&p, &b);
-                        string SpeakerLabel(b.buf, b.len);
-                        if (SpeakerLabel.rfind("RC_", 0) == 0) {
-                            SpeakerLabel.erase(0, 3);
-                        }
-                        map<string, string>::iterator Extra_SpeakerLabel = audioChannelFormat_Content.Extra.find("ChannelLayout");
-                        map<string, string>::iterator Extra_Type = audioChannelFormat_Content.Extra.find("Type");
-                        if (Extra_SpeakerLabel == audioChannelFormat_Content.Extra.end() || Extra_SpeakerLabel->second == SpeakerLabel) {
-                            audioChannelFormat_Content.Extra["ChannelLayout"]  = SpeakerLabel;
-                            audioChannelFormat_Content.Extra["Type"] = "Static";
-                        }
-                        else if (Extra_Type != audioChannelFormat_Content.Extra.end()) {
-                            audioChannelFormat_Content.Extra.clear();
-                            audioChannelFormat_Content.Extra["Type"] = "Dynamic";
-                            tfsxml_leave(&p, &b); // audioBlockFormat
-                            tfsxml_leave(&p, &b); // audioChannelFormat
+            else if (!tfsxml_strcmp_charp(b, "audioBlockFormat")) {
+                if (!tfsxml_enter(&p))
+                {
+                    for (;;) {
+                        if (tfsxml_next(&p, &b))
                             break;
+                        if (!tfsxml_strcmp_charp(b, "speakerLabel")) {
+                            tfsxml_value(&p, &b);
+                            string SpeakerLabel = tfsxml_decode(b);
+                            if (SpeakerLabel.rfind("RC_", 0) == 0) {
+                                SpeakerLabel.erase(0, 3);
+                            }
+                            map<string, string>::iterator Extra_SpeakerLabel = audioChannelFormat_Content.Extra.find("ChannelLayout");
+                            map<string, string>::iterator Extra_Type = audioChannelFormat_Content.Extra.find("Type");
+                            if (Extra_SpeakerLabel == audioChannelFormat_Content.Extra.end() || Extra_SpeakerLabel->second == SpeakerLabel) {
+                                audioChannelFormat_Content.Extra["ChannelLayout"] = SpeakerLabel;
+                                audioChannelFormat_Content.Extra["Type"] = "Static";
+                            }
+                            else if (Extra_Type != audioChannelFormat_Content.Extra.end()) {
+                                audioChannelFormat_Content.Extra.clear();
+                                audioChannelFormat_Content.Extra["Type"] = "Dynamic";
+                                tfsxml_leave(&p); // audioBlockFormat
+                                tfsxml_leave(&p); // audioChannelFormat
+                                break;
+                            }
                         }
                     }
                 }
@@ -805,6 +893,57 @@ void file_adm_private::audioFormatExtended()
     }
 }
 
+void file_adm_private::frameHeader()
+{
+    tfsxml_string a, v;
+    tfsxml_enter(&p);
+    while (!tfsxml_next(&p, &v)) {
+        if (!tfsxml_strcmp_charp(v, "frameFormat")) {
+            while (!tfsxml_attr(&p, &a, &v)) {
+                if (!tfsxml_strcmp_charp(a, "duration")) {
+                    if (IsSub)
+                        More["FrameRate"] = Ztring().From_Number(1 / TimeCodeToFloat(tfsxml_decode(v))).To_UTF8();
+                    else
+                        More["Duration"] = Ztring().From_Number(TimeCodeToFloat(tfsxml_decode(v)) * 1000, 0).To_UTF8();
+                }
+                if (!tfsxml_strcmp_charp(a, "flowID")) {
+                    More["FlowID"] = tfsxml_decode(v);
+                }
+                if (!tfsxml_strcmp_charp(a, "start")) {
+                    More["TimeCode_FirstFrame"] = tfsxml_decode(v);
+                }
+                if (!tfsxml_strcmp_charp(a, "type")) {
+                    More["Metadata_Format_Type"] = tfsxml_decode(v);
+                }
+            }
+        }
+        if (!tfsxml_strcmp_charp(v, "transportTrackFormat")) {
+            transportTrackFormat();
+        }
+    }
+}
+
+void file_adm_private::transportTrackFormat()
+{
+    Items[item_audioTrack].Items.clear();
+    tfsxml_string b, v;
+    int32u trackID = 0;
+    tfsxml_enter(&p);
+    for (;;) {
+        if (tfsxml_next(&p, &b))
+            break;
+        ELEMENT_START(audioTrack)
+            else if (!tfsxml_strcmp_charp(b, "trackID")) {
+                trackID = Ztring().From_UTF8(v.buf, v.len).To_int32u();
+            }
+        ELEMENT_MIDDLE(audioTrack)
+            else if (!tfsxml_strcmp_charp(b, "audioTrackUIDRef")) {
+                tfsxml_value(&p, &b);
+                chna_Add(trackID, tfsxml_decode(b));
+            }
+        ELEMENT_END(audioTrack)
+    }
+}
 
 //***************************************************************************
 // Constructor/Destructor
@@ -831,31 +970,15 @@ File_Adm::~File_Adm()
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-bool File_Adm::FileHeader_Begin()
+void File_Adm::Streams_Fill()
 {
-    // File must be fully loaded
-    if (!IsSub && Buffer_Size < File_Size)
+    // Clean up
+    if (!File_Adm_Private->Items[item_audioTrack].Items.empty())
     {
-        if (Buffer_Size >= 5 && Buffer[0]!='<' && Buffer[1]!='?' && Buffer[2]!='x' && Buffer[3] != 'm' && Buffer[4]!='l')
-        {
-            Reject();
-            return false;
-        }
-
-        Element_WaitForMoreData();
-        return false; //Must wait for more data
+        if (File_Adm_Private->Items[item_audioTrack].Items[0].StringVectors[audioTrack_audioTrackUIDRef].empty())
+            File_Adm_Private->Items[item_audioTrack].Items.erase(File_Adm_Private->Items[item_audioTrack].Items.begin());
     }
 
-    if (tfsxml_init(&File_Adm_Private->p, (void*)(Buffer), Buffer_Size))
-        return true;
-    File_Adm_Private->parse();
-    if (File_Adm_Private->Items[item_audioContent].Items.empty())
-    {
-        Reject();
-        return false;
-    }
-
-
     #define FILL_COUNT(NAME,FIELD) \
         if (!File_Adm_Private->Items[item_##NAME].Items.empty()) \
             Fill(Stream_Audio, 0, "NumberOf" FIELD "s", File_Adm_Private->Items[item_##NAME].Items.size());
@@ -866,25 +989,38 @@ bool File_Adm::FileHeader_Begin()
             string P = Apply_Init(*this, __T(FIELD), i, File_Adm_Private->Items[item_##NAME], Summary); \
 
     #define FILL_A(NAME,ATTRIBUTE,FIELD) \
-        Fill(Stream_Audio, StreamPos_Last, (P + ' ' + FIELD).c_str(), File_Adm_Private->Items[item_##NAME].Items[i].Strings[NAME##_##ATTRIBUTE].c_str(), Unlimited, true); \
+        Fill(Stream_Audio, StreamPos_Last, (P + ' ' + FIELD).c_str(), File_Adm_Private->Items[item_##NAME].Items[i].Strings[NAME##_##ATTRIBUTE].c_str(), Unlimited, true, true); \
 
     #define FILL_E(NAME,ATTRIBUTE,FIELD) \
+        { \
+        ZtringList List; \
+        List.Separator_Set(0, " + "); \
         for (size_t j = 0; j < File_Adm_Private->Items[item_##NAME].Items[i].StringVectors[NAME##_##ATTRIBUTE].size(); j++) { \
-            Fill(Stream_Audio, StreamPos_Last, (P + ' ' + FIELD).c_str(), File_Adm_Private->Items[item_##NAME].Items[i].StringVectors[NAME##_##ATTRIBUTE][j].c_str(), Unlimited, true); \
+            List.push_back(Ztring().From_UTF8(File_Adm_Private->Items[item_##NAME].Items[i].StringVectors[NAME##_##ATTRIBUTE][j].c_str())); \
+        } \
+        string FieldName = P; \
+        if (FIELD[0]) \
+        { \
+            FieldName += ' '; \
+            FieldName += FIELD; \
+        } \
+        Fill(Stream_Audio, StreamPos_Last, FieldName.c_str(), List.Read(), true); \
         } \
 
     #define LINK(NAME,FIELD,VECTOR,TARGET) \
         Apply_SubStreams(*this, P + " LinkedTo_" FIELD "_Pos", File_Adm_Private->Items[item_##NAME].Items[i], NAME##_##VECTOR, File_Adm_Private->Items[item_##TARGET]); \
 
     //Filling
-    Accept("ADM");
     Stream_Prepare(Stream_Audio);
     if (!IsSub)
         Fill(Stream_Audio, StreamPos_Last, Audio_Format, "ADM");
 
-    Fill(Stream_Audio, StreamPos_Last, "Metadata_Format", "ADM, Version " + Ztring::ToZtring(File_Adm_Private->Version).To_UTF8());
+    Fill(Stream_Audio, StreamPos_Last, "Metadata_Format", "ADM, Version " + Ztring::ToZtring(File_Adm_Private->Version).To_UTF8() + File_Adm_Private->More["Metadata_Format"]);
     if (!MuxingMode.empty())
         Fill(Stream_Audio, StreamPos_Last, "Metadata_MuxingMode", MuxingMode);
+    for (map<string, string>::iterator It = File_Adm_Private->More.begin(); It != File_Adm_Private->More.end(); ++It)
+        //if (It->first != "Metadata_Format")
+            Fill(Stream_Audio, StreamPos_Last, It->first.c_str(), It->second);
     if (File_Adm_Private->Items[item_audioProgramme].Items.size() == 1 && File_Adm_Private->Items[item_audioProgramme].Items[0].Strings[audioProgramme_audioProgrammeName] == "Atmos_Master") {
         if (!File_Adm_Private->DolbyProfileCanNotBeVersion1 && File_Adm_Private->Version>1)
             File_Adm_Private->DolbyProfileCanNotBeVersion1=true;
@@ -929,7 +1065,7 @@ bool File_Adm::FileHeader_Begin()
     size_t TotalCount = 0;
     for (size_t i = 0; i < item_Max; i++)
         TotalCount += File_Adm_Private->Items[i].Items.size();
-    bool Full = TotalCount < 100 ? true : false;
+    bool Full = TotalCount < 0x1000 ? true : false;
     FILL_COUNT(audioProgramme, "Programme");
     FILL_COUNT(audioContent, "Content");
     FILL_COUNT(audioObject, "Object");
@@ -941,8 +1077,12 @@ bool File_Adm::FileHeader_Begin()
         FILL_COUNT(audioTrackFormat, "TrackFormat");
         FILL_COUNT(audioStreamFormat, "StreamFormat");
     }
+    #if MEDIAINFO_ADVANCED
     vector<string> Errors_Field[error_Type_Max];
     vector<string> Errors_Value[error_Type_Max];
+    MediaInfo_Config::adm_profile Config_AdmProfile=MediaInfoLib::Config.AdmProfile();
+    bool WarningError=MediaInfoLib::Config.WarningError();
+    #endif
 
     FILL_START(audioProgramme, audioProgrammeName, "Programme")
         if (Full)
@@ -977,15 +1117,27 @@ bool File_Adm::FileHeader_Begin()
             File_Adm_Private->Items[item_audioProgramme].Items[i].Errors->push_back(audioProgrammeID + " is not a valid form (APR_wwww form, wwww is hexadecimal value)");
         }
 
-
+        #if MEDIAINFO_ADVANCED
         for (size_t k = 0; k < error_Type_Max; k++) {
             if (!File_Adm_Private->Items[item_audioProgramme].Items[i].Errors[k].empty()) {
                 for (size_t j = 0; j < File_Adm_Private->Items[item_audioProgramme].Items[i].Errors[k].size(); j++) {
-                    Errors_Field[k].push_back("audioProgramme");
-                    Errors_Value[k].push_back(File_Adm_Private->Items[item_audioProgramme].Items[i].Errors[k][j]);
+                    Errors_Field[WarningError?Error:k].push_back("audioProgramme");
+                    Errors_Value[WarningError?Error:k].push_back(File_Adm_Private->Items[item_audioProgramme].Items[i].Errors[k][j]);
                 }
             }
         }
+
+        //TODO: expand this proof of concept
+        if (Config_AdmProfile.Ebu3392==1)
+        {
+            const string& audioProgrammeName = File_Adm_Private->Items[item_audioProgramme].Items[i].Strings[audioProgramme_audioProgrammeName];
+            if (Ztring().From_UTF8(audioProgrammeName).size() > 32)
+            {
+                Errors_Field[Error].push_back("audioProgramme");
+                Errors_Value[Error].push_back("audioProgrammeName length is more than EBU Tech 3392 constraint");
+            }
+        }
+        #endif // MEDIAINFO_ADVANCED
     }
 
     FILL_START(audioContent, audioContentName, "Content")
@@ -1005,7 +1157,7 @@ bool File_Adm::FileHeader_Begin()
             Summary += __T(')');
             Fill(StreamKind_Last, StreamPos_Last, P.c_str(), Summary, true);
         }
-}
+    }
 
     FILL_START(audioObject, audioObjectName, "Object")
         if (Full)
@@ -1060,10 +1212,24 @@ bool File_Adm::FileHeader_Begin()
     }
 
     if (Full) {
-            FILL_START(audioTrackUID, UID, "TrackUID")
+        FILL_START(audioTrackUID, UID, "TrackUID")
             FILL_A(audioTrackUID, UID, "ID");
             FILL_A(audioTrackUID, bitDepth, "BitDepth");
             FILL_A(audioTrackUID, sampleRate, "SamplingRate");
+            string& ID = File_Adm_Private->Items[item_audioTrackUID].Items[i].Strings[audioTrackUID_UID];
+            for (size_t j = 0; j < File_Adm_Private->Items[item_audioTrack].Items.size(); j++)
+            {
+                Item_Struct& Item = File_Adm_Private->Items[item_audioTrack].Items[j];
+                vector<string>& Ref = Item.StringVectors[audioTrack_audioTrackUIDRef];
+                for (size_t k = 0; k < Ref.size(); k++)
+                {
+                    if (Ref[k] == ID)
+                    {
+                        Fill(Stream_Audio, 0, (P + " TrackIndex/String").c_str(), j + 1);
+                        Fill_SetOptions(Stream_Audio, 0, (P + " TrackIndex/String").c_str(), "Y NIN");
+                    }
+                }
+            }
             LINK(audioTrackUID, "ChannelFormat", audioChannelFormatIDRef, audioChannelFormat);
             LINK(audioTrackUID, "PackFormat", audioPackFormatIDRef, audioPackFormat);
             LINK(audioTrackUID, "TrackFormat", audioTrackFormatIDRef, audioTrackFormat);
@@ -1087,9 +1253,22 @@ bool File_Adm::FileHeader_Begin()
             LINK(audioStreamFormat, "TrackFormat", audioTrackFormatIDRef, audioTrackFormat);
         }
     }
-    else
+
+    if (!File_Adm_Private->Items[item_audioTrack].Items.empty())
+    {
+        Fill(Stream_Audio, 0, "Transport0", "Yes");
+        FILL_START(audioTrack, Summary, "Transport0 TrackIndex")
+            FILL_E(audioTrack, audioTrackUIDRef, "");
+            if (Full)
+                LINK(audioTrack, "TrackUID", audioTrackUIDRef, audioTrackUID);
+        }
+
+    }
+
+    if (!Full)
         Fill(Stream_Audio, 0, "PartialDisplay", "Yes");
 
+    #if MEDIAINFO_ADVANCED
     for (size_t k = 0; k < error_Type_Max; k++) {
         if (!Errors_Field[k].empty()) {
             Fill(StreamKind_Last, StreamPos_Last, error_Type_String[k], Errors_Field[k].size());
@@ -1098,16 +1277,67 @@ bool File_Adm::FileHeader_Begin()
             }
         }
     }
+   #endif // MEDIAINFO_ADVANCED
 
     Element_Offset=File_Size;
-    delete File_Adm_Private; File_Adm_Private = NULL;
+}
 
+//***************************************************************************
+// Buffer - File header
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+bool File_Adm::FileHeader_Begin()
+{
+    // File must be fully loaded
+    if (!IsSub && Buffer_Size < File_Size)
+    {
+        if (Buffer_Size && Buffer[0] != '<')
+        {
+            Reject();
+            return false;
+        }
+
+        Element_WaitForMoreData();
+        return false; //Must wait for more data
+    }
+
+    if (tfsxml_init(&File_Adm_Private->p, (void*)(Buffer), Buffer_Size))
+        return true;
+    File_Adm_Private->IsSub = IsSub;
+    File_Adm_Private->parse();
+    if (File_Adm_Private->Items[item_audioContent].Items.empty())
+    {
+        Reject();
+        return false;
+    }
 
     //All should be OK...
-    Fill("ADM");
+    Accept("ADM");
     return true;
 }
 
+void File_Adm::chna_Add(int32u Index, const string& TrackUID)
+{
+    File_Adm_Private->chna_Add(Index, TrackUID);
+}
+
+void* File_Adm::chna_Move()
+{
+    if (!File_Adm_Private)
+        return NULL;
+    return &File_Adm_Private->Items[item_audioTrack];
+}
+
+void File_Adm::chna_Move(File_Adm* Adm)
+{
+    if (!Adm)
+        return;
+    if (!File_Adm_Private)
+        File_Adm_Private = new file_adm_private();
+    File_Adm_Private->Items[item_audioTrack] = Adm->File_Adm_Private->Items[item_audioTrack];
+}
+
 } //NameSpace
 
 #endif //MEDIAINFO_ADM_YES
