@@ -115,6 +115,11 @@ enum generic
     Generic_Video_Delay_String3,
     Generic_Video_Delay_String4,
     Generic_Video_Delay_String5,
+    Generic_TimeCode_FirstFrame,
+    Generic_TimeCode_LastFrame,
+    Generic_TimeCode_DropFrame,
+    Generic_TimeCode_Settings,
+    Generic_TimeCode_Source,
     Generic_StreamSize,
     Generic_StreamSize_String,
     Generic_StreamSize_String1,
@@ -688,6 +693,8 @@ enum video
     Video_FrameRate_Original_String,
     Video_FrameRate_Original_Num,
     Video_FrameRate_Original_Den,
+    Video_FrameRate_Real,
+    Video_FrameRate_Real_String,
     Video_FrameCount,
     Video_Source_FrameCount,
     Video_Standard,
@@ -749,6 +756,8 @@ enum video
     Video_TimeStamp_FirstFrame_String4,
     Video_TimeStamp_FirstFrame_String5,
     Video_TimeCode_FirstFrame,
+    Video_TimeCode_LastFrame,
+    Video_TimeCode_DropFrame,
     Video_TimeCode_Settings,
     Video_TimeCode_Source,
     Video_Gop_OpenClosed,
@@ -1069,6 +1078,11 @@ enum audio
     Audio_Video0_Delay_String3,
     Audio_Video0_Delay_String4,
     Audio_Video0_Delay_String5,
+    Audio_TimeCode_FirstFrame,
+    Audio_TimeCode_LastFrame,
+    Audio_TimeCode_DropFrame,
+    Audio_TimeCode_Settings,
+    Audio_TimeCode_Source,
     Audio_ReplayGain_Gain,
     Audio_ReplayGain_Gain_String,
     Audio_ReplayGain_Peak,
@@ -1209,6 +1223,41 @@ enum text
     Text_Duration_String3,
     Text_Duration_String4,
     Text_Duration_String5,
+    Text_Duration_Start2End,
+    Text_Duration_Start2End_String,
+    Text_Duration_Start2End_String1,
+    Text_Duration_Start2End_String2,
+    Text_Duration_Start2End_String3,
+    Text_Duration_Start2End_String4,
+    Text_Duration_Start2End_String5,
+    Text_Duration_Start_Command,
+    Text_Duration_Start_Command_String,
+    Text_Duration_Start_Command_String1,
+    Text_Duration_Start_Command_String2,
+    Text_Duration_Start_Command_String3,
+    Text_Duration_Start_Command_String4,
+    Text_Duration_Start_Command_String5,
+    Text_Duration_Start,
+    Text_Duration_Start_String,
+    Text_Duration_Start_String1,
+    Text_Duration_Start_String2,
+    Text_Duration_Start_String3,
+    Text_Duration_Start_String4,
+    Text_Duration_Start_String5,
+    Text_Duration_End,
+    Text_Duration_End_String,
+    Text_Duration_End_String1,
+    Text_Duration_End_String2,
+    Text_Duration_End_String3,
+    Text_Duration_End_String4,
+    Text_Duration_End_String5,
+    Text_Duration_End_Command,
+    Text_Duration_End_Command_String,
+    Text_Duration_End_Command_String1,
+    Text_Duration_End_Command_String2,
+    Text_Duration_End_Command_String3,
+    Text_Duration_End_Command_String4,
+    Text_Duration_End_Command_String5,
     Text_Duration_FirstFrame,
     Text_Duration_FirstFrame_String,
     Text_Duration_FirstFrame_String1,
@@ -1223,6 +1272,7 @@ enum text
     Text_Duration_LastFrame_String3,
     Text_Duration_LastFrame_String4,
     Text_Duration_LastFrame_String5,
+    Text_Duration_Base,
     Text_Source_Duration,
     Text_Source_Duration_String,
     Text_Source_Duration_String1,
@@ -1260,6 +1310,10 @@ enum text
     Text_Width_String,
     Text_Height,
     Text_Height_String,
+    Text_DisplayAspectRatio,
+    Text_DisplayAspectRatio_String,
+    Text_DisplayAspectRatio_Original,
+    Text_DisplayAspectRatio_Original_String,
     Text_FrameRate_Mode,
     Text_FrameRate_Mode_String,
     Text_FrameRate,
@@ -1321,6 +1375,13 @@ enum text
     Text_Video0_Delay_String3,
     Text_Video0_Delay_String4,
     Text_Video0_Delay_String5,
+    Text_TimeCode_FirstFrame,
+    Text_TimeCode_LastFrame,
+    Text_TimeCode_DropFrame,
+    Text_TimeCode_Settings,
+    Text_TimeCode_Source,
+    Text_TimeCode_MaxFrameNumber,
+    Text_TimeCode_MaxFrameNumber_Theory,
     Text_StreamSize,
     Text_StreamSize_String,
     Text_StreamSize_String1,
@@ -1396,6 +1457,14 @@ enum text
     Text_Encoded_Date,
     Text_Tagged_Date,
     Text_Encryption,
+    Text_Events_Total,
+    Text_Events_PopOn,
+    Text_Events_RollUp,
+    Text_Events_PaintOn,
+    Text_Lines_Count,
+    Text_Lines_MaxCountPerEvent,
+    Text_FirstDisplay_Delay_Frames,
+    Text_FirstDisplay_Type,
 };
 
 //---------------------------------------------------------------------------
@@ -1529,9 +1598,12 @@ enum other
     Other_TimeStamp_FirstFrame_String4,
     Other_TimeStamp_FirstFrame_String5,
     Other_TimeCode_FirstFrame,
+    Other_TimeCode_LastFrame,
+    Other_TimeCode_DropFrame,
     Other_TimeCode_Settings,
     Other_TimeCode_Striped,
     Other_TimeCode_Striped_String,
+    Other_TimeCode_Source,
     Other_StreamSize,
     Other_StreamSize_String,
     Other_StreamSize_String1,
