@@ -98,6 +98,9 @@
 #if defined(MEDIAINFO_MXF_YES)
     #include "MediaInfo/Multiple/File_Mxf.h"
 #endif
+#if defined(MEDIAINFO_NSV_YES)
+    #include "MediaInfo/Multiple/File_Nsv.h"
+#endif
 #if defined(MEDIAINFO_NUT_YES)
     #include "MediaInfo/Multiple/File_Nut.h"
 #endif
@@ -498,6 +501,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_MXF_YES)
         Parser.push_back(new File_Mxf());
     #endif
+    #if defined(MEDIAINFO_NSV_YES)
+        Parser.push_back(new File_Nsv());
+    #endif
     #if defined(MEDIAINFO_NUT_YES)
         Parser.push_back(new File_Nut());
     #endif
