@@ -275,6 +275,8 @@ File_DvDif::File_DvDif()
     Speed_FrameCount_Stts_Fluctuation=0;
     Speed_FrameCount_system[0]=0;
     Speed_FrameCount_system[1]=0;
+    FSC_WasSet_Sum=0;
+    FSC_WasNotSet_Sum=0;
     AbstBf_Current=(0x7FFFFF)<<1;
     AbstBf_Previous=(0x7FFFFF)<<1;
     AbstBf_Previous_MaxAbst=0xFFFFFF;
@@ -509,10 +511,10 @@ void File_DvDif::Streams_Fill()
         Fill(Stream_Video, 0, Video_BitRate_Mode, "CBR");
 
     //Delay
-    TimeCode_FirstFrame.FramesPerSecond=(system?25:30);
+    TimeCode_FirstFrame.SetFramesMax(system?24:29);
     if (FrameRate_Multiplicator>=2)
-        TimeCode_FirstFrame.MustUseSecondField=true;
-    if (TimeCode_FirstFrame.IsValid())
+        TimeCode_FirstFrame.SetMustUseSecondField();
+    if (TimeCode_FirstFrame.HasValue())
     {
         string TimeCode_FirstFrame_String=TimeCode_FirstFrame.ToString();
         int64u TimeCode_FirstFrame_ms=TimeCode_FirstFrame.ToMilliseconds();
@@ -573,7 +575,7 @@ void File_DvDif::Streams_Finish()
     }
 
     #ifdef MEDIAINFO_DVDIF_ANALYZE_YES
-        if (Config->File_DvDif_Analysis_Get())
+        if (Config->File_DvDif_Analysis_Get() && !Config->File_FrameIsAlwaysComplete_Get())
         {
             //Errors stats
             Status[IsFinished]=true; //We need to fill it before the call to Errors_Stats_Update
@@ -812,27 +814,34 @@ bool File_DvDif::Demux_UnpacketizeContainer_Test()
      && (CC3(Buffer+Buffer_Offset+6*80)&0xE0F0FF)==0x600000   //Audio 0
      && (CC3(Buffer+Buffer_Offset+7*80)&0xE0F0FF)==0x800000)  //Video 0
     {
-        if (Demux_Offset==0)
+        if (FrameIsAlwaysComplete)
         {
-            Demux_Offset=Buffer_Offset+1;
+            Demux_Offset=Buffer_Size;
         }
+        else
+        {
+            if (Demux_Offset==0)
+            {
+                Demux_Offset=Buffer_Offset+1;
+            }
 
-        while (Demux_Offset+8*80<=Buffer_Size //8 blocks
-            && !((Buffer[Demux_Offset]&0xE0)==0x00   //Speed up the parsing
-              && (CC3(Buffer+Demux_Offset+0*80)&0xE0FCFF)==0x000400   //Header 0 (with FSC==false and FSP==true)
-              && (CC3(Buffer+Demux_Offset+1*80)&0xE0F0FF)==0x200000   //Subcode 0
-              && (CC3(Buffer+Demux_Offset+2*80)&0xE0F0FF)==0x200001   //Subcode 1
-              && (CC3(Buffer+Demux_Offset+3*80)&0xE0F0FF)==0x400000   //VAUX 0
-              && (CC3(Buffer+Demux_Offset+4*80)&0xE0F0FF)==0x400001   //VAUX 1
-              && (CC3(Buffer+Demux_Offset+5*80)&0xE0F0FF)==0x400002   //VAUX 2
-              && (CC3(Buffer+Demux_Offset+6*80)&0xE0F0FF)==0x600000   //Audio 0
-              && (CC3(Buffer+Demux_Offset+7*80)&0xE0F0FF)==0x800000)) //Video 0
-                Demux_Offset++;
+            while (Demux_Offset+8*80<=Buffer_Size //8 blocks
+                && !((Buffer[Demux_Offset]&0xE0)==0x00   //Speed up the parsing
+                  && (CC3(Buffer+Demux_Offset+0*80)&0xE0FCFF)==0x000400   //Header 0 (with FSC==false and FSP==true)
+                  && (CC3(Buffer+Demux_Offset+1*80)&0xE0F0FF)==0x200000   //Subcode 0
+                  && (CC3(Buffer+Demux_Offset+2*80)&0xE0F0FF)==0x200001   //Subcode 1
+                  && (CC3(Buffer+Demux_Offset+3*80)&0xE0F0FF)==0x400000   //VAUX 0
+                  && (CC3(Buffer+Demux_Offset+4*80)&0xE0F0FF)==0x400001   //VAUX 1
+                  && (CC3(Buffer+Demux_Offset+5*80)&0xE0F0FF)==0x400002   //VAUX 2
+                  && (CC3(Buffer+Demux_Offset+6*80)&0xE0F0FF)==0x600000   //Audio 0
+                  && (CC3(Buffer+Demux_Offset+7*80)&0xE0F0FF)==0x800000)) //Video 0
+                    Demux_Offset++;
 
-        if (Demux_Offset+8*80>Buffer_Size && File_Offset+Buffer_Size!=File_Size)
-            return false; //No complete frame
-        if (Demux_Offset+8*80>Buffer_Size && File_Offset+Buffer_Size==File_Size)
-            Demux_Offset=(size_t)(File_Size-File_Offset); //Using the complete buffer (no next sync)
+            if (Demux_Offset+8*80>Buffer_Size && File_Offset+Buffer_Size!=File_Size)
+                return false; //No complete frame
+            if (Demux_Offset+8*80>Buffer_Size && File_Offset+Buffer_Size==File_Size)
+                Demux_Offset=(size_t)(File_Size-File_Offset); //Using the complete buffer (no next sync)
+        }
 
         Element_Code=-1;
         FrameInfo.DTS=FrameInfo.PTS=Speed_FrameCount_system[0]*100100000/3+Speed_FrameCount_system[1]*40000000;
@@ -1367,8 +1376,6 @@ void File_DvDif::timecode()
 
     //Parsing
     int8u Frames_Units, Frames_Tens, Seconds_Units, Seconds_Tens, Minutes_Units, Minutes_Tens, Hours_Units, Hours_Tens;
-    int64u MilliSeconds=0;
-    int8u  Frames=0;
     bool   DropFrame=false;
     bool   FieldIndication;
     BS_Begin();
@@ -1380,9 +1387,7 @@ void File_DvDif::timecode()
     else        //525/60
         Get_SB (DropFrame,                                      "DP - Drop frame"); //525/60
     Get_S1 (2, Frames_Tens,                                     "Frames (Tens)");
-    Frames+=Frames_Tens*10;
     Get_S1 (4, Frames_Units,                                    "Frames (Units)");
-    Frames+=Frames_Units;
 
     if (!DSF_IsValid)
         Get_SB(FieldIndication,                                 "BGF0 or PC");
@@ -1391,9 +1396,7 @@ void File_DvDif::timecode()
     else        //525/60
         Get_SB(FieldIndication,                                 "PC - Biphase mark polarity correction"); //0=even; 1=odd
     Get_S1 (3, Seconds_Tens,                                    "Seconds (Tens)");
-    MilliSeconds+=Seconds_Tens*10*1000;
     Get_S1 (4, Seconds_Units,                                   "Seconds (Units)");
-    MilliSeconds+=Seconds_Units*1000;
 
     if (!DSF_IsValid)
         Skip_SB(                                                "BGF2 or BGF0");
@@ -1402,9 +1405,7 @@ void File_DvDif::timecode()
     else        //525/60
         Skip_SB(                                                "BGF0 - Binary group flag");
     Get_S1 (3, Minutes_Tens,                                    "Minutes (Tens)");
-    MilliSeconds+=Minutes_Tens*10*60*1000;
     Get_S1 (4, Minutes_Units,                                   "Minutes (Units)");
-    MilliSeconds+=Minutes_Units*60*1000;
 
     if (!DSF_IsValid)
         Skip_SB(                                                "PC or BGF1");
@@ -1414,23 +1415,30 @@ void File_DvDif::timecode()
         Skip_SB(                                                "BGF1 - Binary group flag");
     Skip_SB(                                                    "BGF2 - Binary group flag");
     Get_S1 (2, Hours_Tens,                                      "Hours (Tens)");
-    MilliSeconds+=Hours_Tens*10*60*60*1000;
     Get_S1 (4, Hours_Units,                                     "Hours (Units)");
-    MilliSeconds+=Hours_Units*60*60*1000;
-    Element_Info1(Ztring().Duration_From_Milliseconds(MilliSeconds+((DSF_IsValid && Frames!=45)?((int64u)(Frames/(DSF?25.000:29.970)*1000)):0)));
     BS_End();
 
-    if (!TimeCode_FirstFrame.HasValue() && MilliSeconds!=167185000) //if all bits are set to 1, this is not a valid timestamp
-    {
-        TimeCode_FirstFrame=TimeCode(Hours_Tens  *10+Hours_Units,
-                                     Minutes_Tens*10+Minutes_Units,
-                                     Seconds_Tens*10+Seconds_Units,
-                                     (DSF_IsValid && Frames!=45)?(Frames_Tens*10+Frames_Units):0, //if all bits are set to 1, this is not a valid frame number
-                                     0, //Unknown
-                                     DropFrame,
-                                     false, //Unknown
-                                     false);
-    }
+    FILLING_BEGIN()
+        auto HH=Hours_Tens*10+Hours_Units;
+        auto MM=Minutes_Tens*10+Minutes_Units;
+        auto SS=Seconds_Tens*10+Seconds_Units;
+        if (HH+MM+SS!=215) //if all bits are set to 1, this is not a valid timestamp
+        {
+            auto FF=Frames_Tens*10+Frames_Units;
+            auto TC=TimeCode(HH,
+                             MM,
+                             SS,
+                             (DSF_IsValid && FF!=45)?FF:0, //if all bits are set to 1, this is not a valid frame number
+                             0, //Unknown
+                             DropFrame,
+                             false, //Unknown
+                             false);
+            Element_Info1(TC.ToString());
+            if (!TimeCode_FirstFrame.HasValue())
+                TimeCode_FirstFrame=TC;
+        }
+
+    FILLING_END()
 }
 
 //---------------------------------------------------------------------------
