@@ -52,7 +52,7 @@ public :
         {}
     };
     static avcintra_header AVC_Intra_Headers_Data(int32u CodecID);
-    static int32u AVC_Intra_CodecID_FromMeta(int32u Height, int32u Fields, int32u SampleDuration, int32u TimeScale, int32u SizePerFrame);
+    static int32u AVC_Intra_CodecID_FromMeta(int32u Width, int32u Height, int32u Fields, int32u SampleDuration, int32u TimeScale, int32u SizePerFrame);
 
 private :
     File_Avc(const File_Avc &File_Avc); //No copy
@@ -423,8 +423,8 @@ private :
     hdr                                 HDR;
 
 
-    int16u  maximum_content_light_level;
-    int16u  maximum_frame_average_light_level;
+    Ztring  maximum_content_light_level;
+    Ztring  maximum_frame_average_light_level;
 
     void consumer_camera_1();
     void consumer_camera_2();
